summaryrefslogtreecommitdiff
path: root/drivers/cpufreq
diff options
context:
space:
mode:
authorBai Ping <ping.bai@nxp.com>2016-08-19 18:00:28 +0800
committerLeonard Crestez <leonard.crestez@nxp.com>2018-08-24 12:41:33 +0300
commit3773894e9b0ad484c2c361cde88989f384bc6158 (patch)
tree190ea15b09decb9aaa0f2a7acfc74257afe402d6 /drivers/cpufreq
parent2334758f1fe50437b8ad099013c50a93cd2d1eb5 (diff)
MLK-13096-02 cpufreq: imx: update the cpufeq for imx6ll
According the the latest datasheet, we updated the lowest OPP to 198MHz. So we need to update the cpufreq code to fix the syttem hang issue when run 'cpufreq-info' in low bus mode on i.MX6ULL. Signed-off-by: Bai Ping <ping.bai@nxp.com>
Diffstat (limited to 'drivers/cpufreq')
-rw-r--r--drivers/cpufreq/imx6q-cpufreq.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/cpufreq/imx6q-cpufreq.c b/drivers/cpufreq/imx6q-cpufreq.c
index 14884d233111..8887b1d92af1 100644
--- a/drivers/cpufreq/imx6q-cpufreq.c
+++ b/drivers/cpufreq/imx6q-cpufreq.c
@@ -25,7 +25,7 @@
#define FREQ_1P2_GHZ 1200000000
#define FREQ_396_MHZ 396000
#define FREQ_696_MHZ 696000
-#define FREQ_99_MHZ 99000
+#define FREQ_198_MHZ 198000
#define FREQ_24_MHZ 24000
static struct regulator *arm_reg;
@@ -71,10 +71,10 @@ static int imx6q_set_target(struct cpufreq_policy *policy, unsigned int index)
/*
* ON i.MX6ULL, the 24MHz setpoint is not seen by cpufreq
* so we neet to prevent the cpufreq change frequency
* from 24MHz to 99Mhz directly. busfreq will handle this
* when exit from low bus mode.
*/
- if (old_freq == FREQ_24_MHZ && new_freq == FREQ_99_MHZ) {
+ if (old_freq == FREQ_24_MHZ && new_freq == FREQ_198_MHZ) {
mutex_unlock(&set_cpufreq_lock);
return 0;
};
@@ -71,10 +71,10 @@ static int imx6q_set_target(struct cpufreq_policy *policy, unsigned int index)
* ON i.MX6ULL, the 24MHz setpoint is not seen by cpufreq
* so we neet to prevent the cpufreq change frequency
- * from 24MHz to 99Mhz directly. busfreq will handle this
+ * from 24MHz to 198Mhz directly. busfreq will handle this
* when exit from low bus mode.
*/